import { FloorFurniture } from "./FloorFurniture";
import { WallFurniture } from "./WallFurniture";
/**
 * FurnitureData class that manage the data of a furniture.
 *
 * @class
 * @memberof Scuti
 */
export declare class FurnitureData {
    /**
     * The furniture instance that we want to retrieve data.
     *
     * @member {FloorFurniture | WallFurniture}
     * @private
     */
    private readonly _furniture;
    /**
     * The furniture data.
     *
     * @member {IFurnitureData}
     * @private
     */
    private _data;
    /**
     * @param {FloorFurniture | WallFurniture} [furniture] - The furniture instance.
     */
    constructor(furniture: FloorFurniture | WallFurniture);
    /**
     * Load the furniture data.
     *
     * @return {void}
     * @private
     */
    private _load;
    /**
     * Reference to the furniture id.
     *
     * @member {number}
     * @readonly
     * @public
     */
    get id(): number;
    /**
     * Reference to the furniture class name.
     *
     * @member {string}
     * @readonly
     * @public
     */
    get className(): string;
    /**
     * Reference to the furniture base name.
     *
     * @member {string}
     * @readonly
     * @public
     */
    get baseName(): string;
    /**
     * Reference to the furniture color id.
     *
     * @member {number}
     * @readonly
     * @public
     */
    get color(): number;
}
