import { FloorFurniture } from "./FloorFurniture";
import { IFurnitureLayerConfiguration } from "../../interfaces/Furniture.interface";
import { HitSprite } from "../interactions/HitSprite";
import { WallFurniture } from "./WallFurniture";
/**
 * FurnitureLayer class.
 *
 * @class
 * @memberof Scuti
 */
export declare class FurnitureLayer extends HitSprite {
    /**
     * The furniture instance.
     *
     * @member {FloorFurniture | WallFurniture}
     * @private
     */
    private readonly _furniture;
    /**
     * The layer id.
     *
     * @member {number | string}
     * @private
     */
    private _layer;
    /**
     * The layer alpha.
     *
     * @member {number}
     * @private
     */
    private _alpha;
    /**
     * The layer tint.
     *
     * @member {number}
     * @private
     */
    private _tint;
    /**
     * The layer z index.
     *
     * @member {number}
     * @private
     */
    private _z;
    /**
     * The layer blend mode.
     *
     * @member {BLEND_MODES}
     * @private
     */
    private _blendMode;
    /**
     * Is the layer flipped.
     *
     * @member {boolean}
     * @private
     */
    private _flip;
    /**
     * The layer frame id.
     *
     * @member {number}
     * @private
     */
    private _frame;
    /**
     * Is the layer interactive.
     *
     * @member {boolean}
     * @private
     */
    private _ignoreMouse;
    /**
     * The layer direction.
     *
     * @member {Direction}
     * @private
     */
    private _direction;
    /**
     * The layer tag.
     *
     * @member {string}
     * @private
     */
    private _tag;
    /**
     * @param {FloorFurniture | WallFurniture} [furniture] - The furniture instance.
     * @param {IFurnitureLayerConfiguration} [configuration] - The layer configuration.
     */
    constructor(furniture: FloorFurniture | WallFurniture, configuration: IFurnitureLayerConfiguration);
    /**
     * Draw the part.
     *
     * @return {void}
     * @private
     */
    private _draw;
    /**
     * Reference to the furniture instance.
     *
     * @member {FloorFurniture | WallFurniture}
     * @readonly
     * @public
     */
    get furniture(): FloorFurniture | WallFurniture;
}
