import { Container } from "pixi.js";
import { FloorFurniture } from "./FloorFurniture";
import { WallFurniture } from "./WallFurniture";
/**
 * FurniturePart class that represent a furniture layer.
 *
 * @class
 * @memberof Scuti
 */
export declare class FurniturePart extends Container {
    /**
     * The furniture instance that is the parent of the part.
     *
     * @member {FloorFurniture | WallFurniture}
     * @private
     */
    private _furniture;
    /**
     * The layer id.
     *
     * @member {number}
     * @private
     */
    private _layer;
    /**
     * The current frame id.
     *
     * @member {number}
     * @private
     */
    private _frame;
    /**
     * @param {FloorFurniture | WallFurniture} [furniture] - The furniture instance.
     * @param {number} [layer] - The layer id.
     */
    constructor(furniture: FloorFurniture | WallFurniture, layer: number);
    /**
     * Draw the part.
     *
     * @return {void}
     * @private
     */
    private _draw;
    /**
     * Switch the part to the next frame and rerender it.
     *
     * @return {void}
     * @private
     */
    nextFrame(): void;
}
