import { Room } from "./Room";
import { Container, Ticker } from "pixi.js";
/**
 * RoomObject class that is extended by the avatars or furnitures.
 *
 * @class
 * @memberof Scuti
 */
export declare class RoomObject extends Container {
    /**
     * Start the animation of the room object.
     *
     * @member {void}
     * @public
     */
    start: () => void;
    /**
     * Stop the animation of the room object.
     *
     * @member {void}
     * @public
     */
    stop: () => void;
    /**
     * The room instance that will be managed by the camera.
     *
     * @member {Room}
     * @private
     */
    private _room;
    /**
     * Destroy the room object and remove it from the canvas
     *
     * @return {void}
     * @public
     */
    destroy(): void;
    /**
     * Reference to the room object room instance.
     *
     * @member {Room}
     * @readonly
     * @public
     */
    get room(): Room;
    /**
     * Update the current room instance.
     *
     * @param {Room} [room] - The new room instance.
     * @public
     */
    set room(room: Room);
    /**
     * Reference to the room animation ticker instance.
     *
     * @member {Ticker}
     * @readonly
     * @public
     */
    get animationTicker(): Ticker;
}
