import { Container } from "pixi.js";
import { RoomObject } from "../RoomObject";
import { Room } from "../Room";
import { Layer } from "@pixi/layers";
/**
 * RoomObjectLayer class that manage all the room objects.
 *
 * @class
 * @memberof Scuti
 */
export declare class RoomObjectLayer extends Container {
    /**
     * The room instance that will be managed by the camera.
     *
     * @member {Room}
     * @private
     */
    private readonly _room;
    /**
     * The object layer.
     *
     * @member {Layer}
     * @private
     */
    private readonly _layer;
    /**
     * @param {Room} [room] - The room instance that we want to visualize.
     */
    constructor(room: Room);
    /**
     * Add the given room object into the object layer of the room.
     *
     * @param {RoomObject} [object] - The room object that we want to add.
     * @return {void}
     * @public
     */
    add(object: RoomObject): void;
    /**
     * Remove the given room object into the object layer of the room.
     *
     * @param {RoomObject} [object] - The room object that we want to remove.
     * @return {void}
     * @public
     */
    remove(object: RoomObject): void;
    /**
     * Reference to the pixi layer.
     *
     * @member {Layer}
     * @readonly
     * @public
     */
    get layer(): Layer;
}
