import { Texture } from "pixi.js";
/**
 * Material class that regroup the color and texture to be applied on the wall or the floor.
 *
 * @class
 * @memberof Scuti
 */
export declare class Material {
    /**
     * The material color.
     *
     * @member {number}
     * @private
     */
    private _color;
    /**
     * The material texture.
     *
     * @member {Texture}
     * @private
     */
    private _texture;
    /**
     * @param {number} [color] - The material color.
     * @param {Texture} [texture] - The material texture.
     **/
    constructor(color: number, texture: Texture);
    /**
     * Reference to the material color.
     *
     * @member {number}
     * @readonly
     * @public
     */
    get color(): number;
    /**
     * Update the material color.
     *
     * @param {number} [color] - The new material color.
     * @public
     */
    set color(color: number);
    /**
     * Reference to the material texture.
     *
     * @member {Texture}
     * @readonly
     * @public
     */
    get texture(): Texture;
    /**
     * Update the material texture.
     *
     * @param {Texture} [texture] - The new material texture.
     * @public
     */
    set texture(texture: Texture);
}
