/**
 * Material class that regroup the color and texture to be applied on the wall or the floor.
 *
 * @class
 * @memberof Scuti
 */
export class Material {
    /**
     * @param {number} [color] - The material color.
     * @param {Texture} [texture] - The material texture.
     **/
    constructor(color, texture) {
        this._color = color;
        this._texture = texture;
    }
    /**
     * Reference to the material color.
     *
     * @member {number}
     * @readonly
     * @public
     */
    get color() {
        return this._color;
    }
    /**
     * Update the material color.
     *
     * @param {number} [color] - The new material color.
     * @public
     */
    set color(color) {
        this._color = color;
    }
    /**
     * Reference to the material texture.
     *
     * @member {Texture}
     * @readonly
     * @public
     */
    get texture() {
        return this._texture;
    }
    /**
     * Update the material texture.
     *
     * @param {Texture} [texture] - The new material texture.
     * @public
     */
    set texture(texture) {
        this._texture = texture;
    }
}
//# sourceMappingURL=Material.js.map