/**
 * Material class that regroup the methods to make beautiful logs.
 *
 * @class
 * @memberof Scuti
 */
export declare class Logger {
    /**
     * The logger name (the name shown on the left of the log).
     *
     * @member {string}
     * @private
     */
    private readonly _name;
    /**
     * @param {string} [name] - The logger name.
     */
    constructor(name: string);
    /**
     * Send a normal log message into the console.
     *
     * @param {string} [message] - The message that will be logged into the console.
     * @return {void}
     * @public
     */
    log(message: string): void;
    /**
     * Send an error log message in the console.
     *
     * @param {string} [message] - The message that will be logged into the console.
     * @return {void}
     * @public
     */
    error(message: string): void;
    /**
     * Send a warning log message in the console.
     *
     * @param {string} [message] - The message that will be logged into the console.
     * @return {void}
     * @public
     */
    warn(message: string): void;
    /**
     * Send an info log message in the console.
     *
     * @param {string} [message] - The message that will be logged into the console.
     * @return {void}
     * @public
     */
    info(message: string): void;
    /**
     * Send a stylized message in the console.
     *
     * @param {string} [backgroundColor] - The color of the background of the message.
     * @param {string} [textColor] - The color of the message.
     * @param {string} [message] - The message that will be logged into the console.
     * @return {void}
     * @public
     */
    private _log;
    /**
     * Reference of the current time of the day formatted in a string.
     *
     * @member {string}
     * @readonly
     * @public
     */
    get time(): string;
    /**
     * Reference of the logger name.
     *
     * @member {string}
     * @readonly
     * @public
     */
    get name(): string;
}
